/**
 * XMLCleanup.java
 * xmlstringparser
 *
 * Flexible Web Solutions
 * Copyright 2006
 */
package com.flexiblewebsolutions.xmlstringparser.utils;

import org.apache.log4j.Logger;

/**
 * Utilities used to remove characters from XML string that will confuse parser
 * 
 * @author dgbuss
 */
public class XMLCleanup {

	private final static Logger logger = Logger.getLogger(XMLCleanup.class);

	/**
	 * Remove the comments from the xml string.
	 * 
	 * @param pageContents - XML String
	 */
	public void removeComments(StringBuffer pageContents) {
		logger.debug("Removing commented elements from XML.");
		// delete comments
		String startComment = "<!--";
		String endComment = "-->";

		while (pageContents.indexOf(startComment) != -1) {
			int startIndex = pageContents.indexOf(startComment);
			int endIndex = pageContents.indexOf(endComment)
					+ endComment.length();
			pageContents.delete(startIndex, endIndex);
		}
		logger.debug("Comment were removed from XML.");
	}
	
    /**
     * Remove tab characters from input
     * @param pXML XMl String
     * @return StringBuffer that has tab characters removed
     */
    public static StringBuffer removeTabChars( StringBuffer pXML )
    {
    	return( removeCharacter( pXML, '\t' ) );
    }
    
    /**
     * Remove new line characters from the xml string if they exist
     * 
     * @param pXML
     *            Xml String
     * @return XML String where new lines have been removed.
     */
    public static StringBuffer removeNewlines( StringBuffer pXML )
    {
    	return( removeCharacter( pXML, '\n' ) );
    }
    
    /**
     * Removes a character from the screen
     * @param pXML Xml String
     * @param pChar Character to remove
     * @return Xml String that is free from offending character
     */
    private static StringBuffer removeCharacter( StringBuffer pXML, char pChar )
    {
        StringBuffer returnXML = new StringBuffer();
        for( int i = 0; i < pXML.length(); i++ )
        {
            if( pXML.charAt( i ) != pChar )
            {
                returnXML.append( pXML.charAt( i ) );
            }
        }
        return ( returnXML );
    }

}
